require 'spec_helper'
require 'gris/grape_extensions/error_helpers'

describe GrisAccounts::AuthorizationHelpers do
  let(:helper) { SpecApiErrorHelper.new }

  context 'require_access_to_account' do
    let(:account_id) { 1 }

    context 'when payload account_ids includes account_id' do
      let(:payload) do
        Hashie::Mash.new(
          'GRIS_JWT_PAYLOAD' => [{ account_ids: [account_id] }]
        )
      end

      before do
        helper.instance_variable_set(:@env, payload)
      end

      it 'assigns @account_ids' do
        helper.require_access_to_account(account_id)
        expect(helper.instance_variable_get(:@account_ids)).to eq [account_id]
      end
    end

    context 'when payload account_ids does not include account_id' do
      let(:payload) do
        Hashie::Mash.new('GRIS_JWT_PAYLOAD' => [{ account_ids: [] }])
      end

      before do
        helper.instance_variable_set(:@env, payload)
      end

      it 'raises Forbidden error' do
        helper.require_access_to_account(account_id)
        expect(helper.message)
          .to eq(message: { message: 'Forbidden.', status: 403 }, status: 403)
        expect(helper.thrown).to eq(:error)
      end
    end
  end

  context 'user_id_from_payload' do
    let(:id) { 'michael-heizer' }

    context 'when payload includes id' do
      let(:payload) { Hashie::Mash.new('GRIS_JWT_PAYLOAD' => [{ id: id }]) }

      before do
        helper.instance_variable_set(:@env, payload)
      end

      it 'assigns @user_id' do
        helper.user_id_from_payload
        expect(helper.instance_variable_get(:@user_id)).to eq id
      end
    end

    context 'when payload does not include id' do
      let(:payload) { Hashie::Mash.new('GRIS_JWT_PAYLOAD' => [{}]) }

      before do
        helper.instance_variable_set(:@env, payload)
      end

      it 'raises Forbidden error' do
        helper.user_id_from_payload
        expect(helper.message)
          .to eq(message: { message: 'Forbidden.', status: 403 }, status: 403)
        expect(helper.thrown).to eq(:error)
      end
    end
  end
end
